@@ -116,8 +116,10 @@ extern double McRun(double Q);
 extern double McEff(double Q);
 extern double MbPole;
 extern double poleQmass(double M_M_, double alpha, int nf);
-extern double Mbp(void);
 
+extern double bPoleMass(void);
+extern double tPoleMass(void);
+    
 extern double MqRun(double mass2GeV, double Q);
 extern double MqEff(double mass2GeV, double Q);
 extern double nfQCD(double Q);
