@@ -28,6 +28,8 @@
 #include "num_in.h"
 #include "comp.h"
 
+#include"../../include/version.h"
+
 static int sub_men__(void)
 {
     int  n, npr, mode=0;
@@ -81,39 +83,51 @@ static int sub_men__(void)
 }
 
 
-
 static void f7_prog(int mode)
 { int pos=1;
   void *pscr=NULL;
-  if(mode>2) 
-  { messanykey(10,15," Highlight the corresponding\n"
-                     "structure function");
-    return;
-  }     
-
-  if(!sf_num[mode-1]) return;
-  
   f3_key[4]=NULL;
 
   for(;;)
-  {  static double xMin=0.0, xMax=1.0, scale = 91.187;
+  {  static double xMin=1E-5, xMax=1.0, q0 = 91.187,qMin=1.5,qMax=1.E4,x0=0.1;
      static int nPoints=100;
-     double f[150];
-     
-     char strmen[]="\030 "
+     static int both=1,LOG=1;  
+     int on[2]={0,0};
+
+
+     char strmen[]="\030"
                   " x-Min = XXX            "
                   " x-Max = YYY            "
+                  " q-Min = QXX            "
+                  " q-Max = QYY            " 
                   " Npoints = NNN          "
-                  " QCD-scale= QQQ         "
+                  " q0      = QQQ          "
+                  " x0      = xXX          "
+                  " log scale argument LOG "  
                   " Display plot x*F(x)    "
-                  " Display plot F(x)      ";
-     
-     improveStr(strmen,"XXX","%.3f",xMin);
-     improveStr(strmen,"YYY","%.3f",xMax);
-     improveStr(strmen,"NNN","%d",nPoints);
-     improveStr(strmen,"QQQ","%.1fGeV",scale); 
+                  " Display plot   F(x)    "
+                  " Display plot   F(Q)    "
+                  " both PDF1&PDF2    BOTH ";
 
-     menu1(54,14,"",strmen,"n_alpha_view",&pscr,&pos);
+               
+     improveStr(strmen,"XXX","%.3E",xMin); 
+     improveStr(strmen,"YYY","%.3E",xMax);
+     improveStr(strmen,"QXX","%.3E",qMin);
+     improveStr(strmen,"QYY","%.3E",qMax);
+     improveStr(strmen,"NNN","%d",nPoints);
+     improveStr(strmen,"QQQ","%.2fGeV",q0); 
+     improveStr(strmen,"xXX","%.2E",x0);
+     if(LOG) improveStr(strmen,"LOG","ON"); else improveStr(strmen,"LOG","OFF");
+     
+     if(mode>2) both=1;
+     if(both){ on[0]=1,on[1]=1;} else  on[mode-1]=1;
+
+     if(!sf_num[0]) on[0]=0;
+     if(!sf_num[1]) on[1]=0;
+     if(sf_num[0]==0 && sf_num[1]==0) return;
+      
+     if(both) improveStr(strmen,"BOTH","ON"); else improveStr(strmen,"BOTH","OFF");
+     menu1(54,10,"PDF plots",strmen,"n_pdf_plots_*",&pscr,&pos);
 
      switch(pos)
      {  case 0: f3_key[4]=f7_prog; 
@@ -125,41 +139,75 @@ static void f7_prog(int mode)
           correctDouble(55,18,"xMax = ",&xMax,1);                  
           break; 
         case 3:
+          correctDouble(55,18,"qMin = ",&qMin,1);
+          break; 
+        case 4:  
+          correctDouble(55,18,"qMax = ",&qMax,1);
+          break; 
+        case 5:
           correctInt(50,18,"nPoints = ",&nPoints,1);
           break; 
-        case 4: 
-          correctDouble(50,18,"QCD-scale = ",&scale,1);
+        case 6: 
+          correctDouble(50,18,"q0 = ",&q0,1);
           break;
-        case 5: case 6:
-         if(xMin>=0 && xMax>xMin && xMax<=1 
-            && nPoints>=3 && nPoints<=150 && scale>0.5)
-         {
+        case 7:
+          correctDouble(50,18,"x0 = ",&x0,1);
+           break;
+        case 8: LOG=!LOG; break;             
+        case 9: case 10: case 11:
+        { double z1,z2;
+          if(pos==11) {z1=qMin;z2=qMax;} else {z1=xMin;z2=xMax;}
+
+          if(z1>=0 && (!LOG||(z2/z1>10) ) && z2>z1 && nPoints>=3 && nPoints<=150 )
+         { int l,i;
+           double * df[2]={NULL,NULL};
+           double f[2][250];
+           char p_name[2][100], title[100];
+           char*xName;
            void * screen;
-           double dx=(xMax-xMin)/(2*nPoints);
-           double be=sf_be[mode-1];
-           int i;
+           
            get_text(1,1,maxCol(),maxRow(),&screen);
-           for(i=0;i<nPoints;i++)
-           {  double x=xMin+(i+0.5)*(xMax-xMin)/nPoints;
-              f[i]=strfun_(mode,x,scale);
-              if(pos==5) f[i]*=x;
-              if(be!=1.) f[i]*=be*pow(1.-x,be-1.);
+//           if(LOG) {z1=log10(z1); z2=log10(z2);}
+           for(l=0;l<2; l++) if(on[l])
+           {  double be=sf_be[l];
+              strFunName(l+1,p_name[l]);
+              sprintf(p_name[l]+strlen(p_name[l]),"(%s)", pinf_int(Nsub,l+1,NULL,NULL));              
+//              sprintf(p_name[l],"pdf%d(%s)", l+1,pinf_int(Nsub,l+1,NULL,NULL) ); 
+              for(i=0;i<nPoints;i++)
+              {  double x=x0,q=q0,z,al;
+                 al=(i+0.5)/(double)nPoints;
+                 if(LOG)  z=pow(z1,1-al)*pow(z2,al); 
+                 else     z=z1+al*(z2-z1);
+                 
+                 if(pos==11) q=z; else x=z;
+                 f[l][i]=strfun_(l+1,x,q);
+                 if(pos==9) f[l][i]*=x;
+//          if(pos==11) f[l][i]/=q*q;
+                 if(be!=1.) f[l][i]*=be*pow(1.-x,be-1.);
+              }
            }
-           {
-              char p_name[20], mess[STRSIZ];
-              strcpy(p_name,pinf_int(Nsub,mode,NULL,NULL));
-              if(pos==5) strcat(p_name,"(x)*x"); else strcat(p_name,"(x)");
-              strFunName(mode,mess);
-              trim(mess);
-              sprintf(mess+strlen(mess)," [QCD-scale = %.1f GeV]",scale); 
-              plot_1(xMin+dx,xMax-dx,nPoints,f,NULL,mess,"x",p_name);  
+//           strcpy(title,"Incoming particle distribution");
+           title[0]=0;  
+           
+           switch(pos)
+           { case  9: sprintf(title+strlen(title)," x*F(x,Q=%.2E)",q0);   break;
+             case 10: sprintf(title+strlen(title)," F(x,Q= %.2E)",q0);     break;
+             case 11: sprintf(title+strlen(title)," F(x=%.2E,Q)",x0);     break;
            }
+           if(pos==11) xName="Q"; else xName="x";
+           if(on[0]&&on[1]) plot_N(title,z1,z2, xName, LOG, 2, nPoints, f[0],NULL,p_name[0],nPoints,f[1],NULL,p_name[1]);
+           else 
+           { if(on[0]) l=0; else l=1;
+              plot_N(title,z1,z2, xName, LOG,1, nPoints, f[l],NULL,p_name[l]);   
+           }  
            put_text(&screen);
          } else messanykey(16,5," Correct input is \n"
                                 "  0<=xMin<xMax<=1,\n"
-                                " QCD-scale > 0.5 GeV\n"
-                                " 3<=nPoints<=150");    
-         break;    
+                                " 3<=nPoints<=150");
+        }                        
+        break;                        
+        case 12: both=!both;    
+        break; 
       }
    }
 }
@@ -198,10 +246,10 @@ static int  in_setting(void)
 
     strmen[0]=strlen(strmen)/6;         
     if(is_polarized(1,Nsub))
-    improveStr(strmen,"FirstPol", "Helicity of  first particle   %.3G",Helicity[0]); 
+    improveStr(strmen,"FirstPol", "Helicity of  first particle   %.3G",(double)Helicity[0]); 
     else improveStr(strmen,"FirstPol", "First  particle unpolarized");
     if(is_polarized(2,Nsub))
-    improveStr(strmen,"SecondPol","Helicity of second particle   %.3G",Helicity[1]); 
+    improveStr(strmen,"SecondPol","Helicity of second particle   %.3G",(double)Helicity[1]); 
     else improveStr(strmen,"SecondPol", "Second particle unpolarized");
 
     strFunName(1,sf_txt); improveStr(strmen,"First","%-45.45s", sf_txt);
@@ -412,7 +460,7 @@ int monte_carlo_menu(void)
                   " IN state               "
                   " Model parameters       "
                   " Constraints            "
-                  " QCD coupling           "
+                  " QCD  alpha & scales    "
                   " Breit-Wigner           "
 	          " Aliases                "
 	          " Cuts                   "
@@ -469,14 +517,56 @@ int monte_carlo_menu(void)
                                                                         
                  
                  if(checkEnergy())   
-                 { if(blind)  return 1;                  
+                 { 
+                    if(blind==1)
+                    { char fname[50];
+                     int i,j;
+                     sprintf(fname,"events_%d.txt", nSess);
+                     FILE * f=fopen(fname,"w");
+                     fprintf(f,"#%s\n", VERSION_);
+                     fprintf(f,"#Type %d -> %d\n", nin_int,nout_int);
+                     fprintf(f,"#Initial_state ");
+                     if(nin_int==1) fprintf(f," P1=0\n");
+                     else
+                     { fprintf(f," P1_3=0  P2_3=0\n");
+                       wrt_sf__(f);
+                     }  
+                     fprintf(f,"#PROCESS  ");
+                     for(i=1;i<=nin_int+nout_int; i++)
+                     { int pcode;
+                       char * pname=pinf_int(Nsub,i,NULL,&pcode);
+                       fprintf(f," %d(%s)", pcode, pname);
+                       if(i==nin_int)  fprintf(f," ->");
+                     } 
+                     fprintf(f,"\n");    
+                     fprintf(f,"#MASSES ");
+                     for(i=0;i<nin_int+nout_int;i++)
+                     {  REAL m;
+                        pinf_int(Nsub,i+1,&m,NULL); 
+                        fprintf(f," %.10E", (double)m);
+                     }   
+                     fprintf(f,"\n");
+  
+                     fprintf(f,"#Cross_section(Width) %E\n",0.);
+                    
+                     fprintf(f,"#Number_of_events %10d\n",0);
+                     fprintf(f,"#Sum_of_weights %12.4E %12.4E \n",0.,0.);
+                     fprintf(f,"#Events  "); 
+                     if(nin_int==2) fprintf(f,"     P1_3 [Gev]        P2_3 [Gev]   ");
+                     for(i=1;i<=nout_int; i++) for(j=1;j<=3;j++) 
+                          fprintf(f,"     P%d_%d [Gev]   ",i+nin_int,j);
+                     integral.old=1;
+                     fclose(f); 
+                     return 1;
+                   }
+                            
                    messanykey(15,15,"Energy is too small!");                   
                    break;
                  }
 
                  if(fillCutArray()) 
                  { if(blind) return 2;
-                   messanykey(15,15,"Can not evaluate cuts limlts"); 
+                   messanykey(15,15,"Can not evaluate cut limits"); 
                    break;
                  }  
         case 11:
@@ -512,6 +602,7 @@ int monte_carlo_menu(void)
                 break;
                  
       }
+//printf("r=%d\n",r);      
       if(r) clearEventMax();
       if(r&2) clearGrid();
       if(r&1)newSession();
