@@ -26,6 +26,7 @@
 #include "comp.h"
 #include "cut.h"
 #include "vp.h"
+#include "runVegas.h"
 
 static void f5_key_prog(int x)
 {
@@ -36,13 +37,15 @@ static void f5_key_prog(int x)
   {  
     char strmen[]="\040"
                   " Virtual W/Z decays          OF5"
-                  " Parallelization          nCORES";  
-        
+                  " Parallelization          nCORES"
+                  " Allow weighted events      OF_ ";   
+ 
     if(VWdecay)  improveStr(strmen,"OF5","ON ");
         else     improveStr(strmen,"OF5","OFF");    
-    improveStr(strmen,"nCORES","%d",nPROCSS);    
+    improveStr(strmen,"nCORES","%d",nPROCSS); 
+    if(regenEvents) improveStr(strmen,"OF_","OFF"); else improveStr(strmen,"OF_","ON");   
                                           
-    menu1(20,18,"Switches",strmen,"s_switch_*",&pscr,&kmenu);
+    menu1(20,18,"Switches",strmen,"n_switch_*",&pscr,&kmenu);
     if(kmenu==1) 
     {  VWdecay=!VWdecay;
        if(checkParam()>0){VWdecay=!VWdecay;checkParam();};
@@ -50,7 +53,7 @@ static void f5_key_prog(int x)
     { char mess[40];
       sprintf(mess,"There are %d processors. To use ", (int) sysconf(_SC_NPROCESSORS_ONLN));
       correctInt(20,22,mess,&nPROCSS,1);
-    }    
+    } else if(kmenu==3) regenEvents=!regenEvents;   
   }
   VZdecay=VWdecay;                     
 }
@@ -202,7 +205,7 @@ int main(int argc,char** argv)
   { char *ch=getenv("nParProc");
     if(ch) sscanf(ch,"%d",&nPROCSS);
   }  
-  
+
   goto_xy(10,10); print("Calculation of constraints.  Please, be patient.");
   escpressed();
   n_comphep();
