@@ -54,7 +54,7 @@ static void writeEvent(double *x,  double  w)
    mkmom(x, &factor_0,&x1,&x2,pvectR);
    
    for(i=0;i<4*(nin_int+nout_int);i++) pvect[i]=pvectR[i];   
-   Scale(pvect,&qR,&qF1,&qF2,&qS);
+   Scale(Nsub,pvect,&qR,&qF1,&qF2,&qS);
    
    if(cb_pow)
    {  double sum=0;
@@ -127,10 +127,11 @@ static void write_event_cap(void)
   fprintf(events_,"#%s\n",VERSION_);
   fprintf(events_,"#Type %d -> %d\n",nin_int,nout_int); 
   fprintf(events_,"#Initial_state\n");
-  fprintf(events_,"  P1_3=%E" , inP1); 
-  if(nin_int>1) fprintf(events_,"  P2_3=%E\n",-inP2);else fprintf(events_,"\n");
-  if(nin_int>1) wrt_sf__(events_);
-
+  if(nin_int==1) fprintf(events_,"  P1_3=0\n");
+  else
+  {  fprintf(events_,"   P1_3=%E  P2_3=%E\n" , inP1,-inP2); 
+     wrt_sf__(events_);
+  }
   fprintf(events_,"#PROCESS  ");
   for(i=1;i<=nin_int+nout_int; i++)
   { int pcode;
@@ -150,12 +151,11 @@ static void write_event_cap(void)
   if(integral.n_it) fprintf(events_,"#Cross_section(Width) %E\n",integral.s1/integral.n_it);
   else   fprintf(events_,"#Cross_section(Width) Unknown\n"); 
   fprintf(events_,"#Number_of_events %10d\n",0);
-  fprintf(events_,"#Sum_of_weights %12.4E %12.4E \n",0.);
+  fprintf(events_,"#Sum_of_weights %12.4E %12.4E \n",0.,0.);
   fprintf(events_,"#Events  "); 
   if(nin_int==2) fprintf(events_,"     P1_3 [Gev]        P2_3 [Gev]   ");
   for(i=1;i<=nout_int; i++) for(j=1;j<=3;j++) 
                           fprintf(events_,"     P%d_%d [Gev]   ",i+nin_int,j);
-
 //  fprintf(events_,"  QCD SCALE    Color  !chains\n");
   fprintf(events_,"  Q_factor   alpha_QCD  Color chains\n");
 
@@ -370,7 +370,7 @@ static double func_(double *x, double wgt)
     factor_0 *= calcCutFactor(pvect)*usrFF(nin_int,nout_int,pvect,p_names,p_codes); 
     if (!factor_0)   goto exi;
 
-    Scale(pvect,&qR,&qF1,&qF2,&qS);
+    Scale(Nsub,pvect,&qR,&qF1,&qF2,&qS);
 /* **  structure function  multiplication */
     if (nin_int == 2) 
     {
