@@ -6,9 +6,15 @@
 #ifndef __PLOT__
 #define __PLOT__
 
+
+extern int   plot_N(char*title,  double xMin, double xMax, char*xName, int xScale, int N,...);
+extern int   plot_Nar(char*file, char*title,  double xMin, double xMax, char*xName,  int xScale, int N, int *Dim,
+               double **f,double**ff,char**Y);
+
 extern void   plot_1(double xMin, double xMax, int dim, 
                     double *f, double *ff,char* upstr, char* xstr, char* ystr);
-extern void plot_2(double hMin1,double hMax1,int nBin1,
+extern void plot_2D(double hMin1,double hMax1,int nBin1,
                    double hMin2,double hMax2,int nBin2,
-            double * f,double *df,char *proces,char* xname,char * yname);
+                   double * f,double *df,char *proces,char* xname,char * yname);
+
 #endif
