@@ -470,7 +470,7 @@ static int  alldiagrams(FILE * fd,  int nsub)
       {  writeF("Prop=1");
          writeDenominators(&dendescript);
          writeF("R*=creal(Prop);\n");
-         writeF(" if(R>Fmax) Fmax=R; else if(R<-Fmax) Fmax=-R;\n");
+         writeF(" if(R>(*Fmax)) (*Fmax)=R; else if(R<-(*Fmax)) (*Fmax)=-R;\n");
       } else  writeF(";\n");
       if(!noCChain)calcColor(cr.ndiagr_+inftmp->firstdiagpos);
       writeF("ans+=R;\n");
@@ -529,7 +529,7 @@ static void  writesubprocess(int nsub,long firstDiag,long totDiag,int* breaker)
 
    if(totDiag==0) 
    { writeF("extern DNN S%d_ext;\n",nsub); 
-     writeF("REAL S%d_ext(double GG,  REAL * momenta,REAL*cb_coeff, int * err)\n{",nsub); 
+     writeF("REAL S%d_ext(double GG,  REAL * momenta, REAL*cb_coeff, double*Fmax, int * err)\n{",nsub); 
      writeF("  return 0;\n}\n");
      outFileClose(); 
      return;
@@ -544,7 +544,7 @@ static void  writesubprocess(int nsub,long firstDiag,long totDiag,int* breaker)
       writeF("};\n");
    } 
    writeF("extern DNN S%d_ext;\n",nsub);
-   writeF("REAL S%d_ext(double GG, REAL * momenta,REAL*cb_coeff,int * err)\n{",nsub);
+   writeF("REAL S%d_ext(double GG, REAL * momenta, REAL*cb_coeff, double*Fmax, int * err)\n{",nsub);
    writeF("REAL  ans=0;\n");
 
    sprintf(fd_name,"%stmp%cden.inf",pathtouser,f_slash);
@@ -610,7 +610,7 @@ static void  writesubprocess(int nsub,long firstDiag,long totDiag,int* breaker)
       writeF("{int i; for(i=0;i<%d;i++) \n",totDiag);
       writeF(
       "{ REAL r=Farr[i](GG,DP,Q0,Q1,Q2,cb_coeff);\n"
-      "  if(r>Fmax) Fmax=r;\n"
+      "  if(r>(*Fmax)) *Fmax=r;\n"
       "  ans+=r;\n"
       "}}\n"
       "return ans;\n}\n"
@@ -779,7 +779,7 @@ static void  make_pinf(void)
 static void  make_den_info(void)
 {  int nden_s,nden_t,nden_0;
 
-   writeF("\n char * den_info_ext(int nsub,int n, int * mass, int * width)\n{\n");
+   writeF("\n char * den_info_ext(int nsub,int n, int * mass, int * width, int*pnum)\n{\n");
    writeF(" switch(nsub){\n");
 
    for (nsub = 1; nsub <= subproc_sq; nsub++)
@@ -792,12 +792,12 @@ static void  make_den_info(void)
       denominatorStatistic(nsub, &nden_s, &nden_t, &nden_0, &den_, NULL); 
       for(n=1 ;den_;den_ = den_->next,n++)
       { int m=0;
-          writeF("\n    case %d: *mass=%d; *width=%d; return \"",
-          n, vararr[den_->mass].num, vararr[den_->width].num);
+          writeF("\n    case %d: *mass=%d; *width=%d;  if(pnum) *pnum=%d; return \"",
+          n, vararr[den_->mass].num, vararr[den_->width].num,den_->pnum);
          while(den_->momStr[m]) fprintf(outFile,"\\%o",den_->momStr[m++]);
          fprintf(outFile,"\";");    
       }  
-      writeF("\n    default:*mass=0; *width=0; return NULL;\n                  }\n");
+      writeF("\n    default:*mass=0; *width=0; if(pnum) *pnum=0; return NULL;\n                  }\n");
  
       release_(&mem_start); 
    }
@@ -1051,7 +1051,7 @@ static int c_prog_int(void)
    memerror=zeroHeep;
    mark_(&heapbeg);
 
-   initvararray(0,'c',3);
+   initvararray(0,'c',NULL);
   /* ======= Initialisation parth ======= */
 
    firstVar=nmodelvar;
@@ -1188,3 +1188,67 @@ int  c_prog(void)
 
  return result; 
 }
+
+int vert_code(polyvars * vardef_ext)
+{
+   
+//   outFile=stdout;
+   labl();   
+   writeF("#include<stdlib.h>\n");
+   writeF("#include<math.h>\n");
+   writeF("#include<complex.h>\n");                 
+   
+   initvararray(0,'c',vardef_ext);
+
+   firstVar=nmodelvar;
+   if(!strcmp( modelvars[firstVar].varname,strongconst))  firstVar--;
+
+   calc_nvars_nfunc();
+
+//   geninf(" nvar_ext",nvars);
+//   geninf(" nfunc_ext",nfunc);
+//   writeF(" static int nvars=%d;\n",nvars);
+   
+   writeF("static char*varName[%d]={\"zero\"",nvars+nfunc+1);
+   sortvars();
+   writeF("};\n");   
+
+   writeF(" static double V[%d];\n",nvars+nfunc+1);
+   
+
+   writeF("static int vertexCoeff(double * coeff_out)\n{\n");
+
+   int    l;  
+
+        
+   for(l=nCommonVars+1;l<=nmodelvar;l++)
+   { 
+      char *ss;
+      if(vararr[l].used && ((modelvars[l].func && modelvars[l].pub==0) || modelvars[l].pwidth) )
+      {  int num;
+         checkNaN=0;
+         if(modelvars[l].pwidth)
+         {  writeF("   %s=aWidth_ext(\"%s\");\n",vararr[l].alias,
+             prtclbase1[modelvars[l].pwidth].name); 
+             checkNaN=1;
+         } else
+         {
+           ss=(char *)readExpression(modelvars[l].func,rd_c,act_c,free);
+/*	   writeF("   %s=%s;\n",vararr[l].alias,ss+3);*/
+	   fprintf(outFile,"   %s=%s;\n",vararr[l].alias,ss+3);
+	   free(ss);
+	 }
+	 if(checkNaN)
+	 {
+    	    sscanf(vararr[l].alias,"V[%d]",&num); 
+            writeF("   if(!isfinite(%s)){ return %d;}\n",vararr[l].alias,num);
+         }
+      }
+   }
+   
+   for(l=0;l<vardef_ext->nvar;l++) if(!strchr( vardef_ext->vars[l].name,'.'))  
+         strcpy(vardef_ext->vars[l].name,vararr[vardef_ext->vars[l].num].alias);
+
+   return nvars;
+}
+
