@@ -5,7 +5,7 @@
 #include "syst2.h"
 #include "physics.h"
 #include "parser.h"
-#include "pvars.h"
+//#include "pvars.h"
 #include "s_files.h"
 #include "out_serv.h"
 #include "procvar.h"
@@ -28,7 +28,7 @@ static void *  rd_hiddenVars(char* s)
 
 static void * act_hiddenVars(char * ch,int n,void ** mm1) {  return PP; }
 
-int initvararray(int nsub, char key, int width)
+int initvararray(int nsub, char key, polyvars * vardef_ext)
 {  int i,j,k,kk,l; 
    catrec    cr;
    FILE * catalog_;   
@@ -50,9 +50,13 @@ int initvararray(int nsub, char key, int width)
    }
    sprintf(vararr[0].alias,"0");
          
+   
+   
+   if(vardef_ext==NULL) 
+   {  
    vardef=&allVars;
    
-   if(width &1) catalog_=fopen(CATALOG_NAME,"rb"); else catalog_=NULL;
+   catalog_=fopen(CATALOG_NAME,"rb");
    
    if(catalog_)while (FREAD1(cr,catalog_)) if(cr.status==1)
    {  
@@ -76,16 +80,16 @@ int initvararray(int nsub, char key, int width)
          clearvardef();
       }
    }
-/*   if(ArcNum) fclose(archiv); */
    whichArchive(0,0);
    if(catalog_) fclose(catalog_);
    ArcNum=0;
-  
+   } else for(i=0;i<vardef_ext->nvar;i++) vararr[vardef_ext->vars[i].num].used=1;  
    for (k = nmodelvar ; k >=0; k--) 
    if( vararr[k].used && modelvars[k].func && (key!='c' || (k>nCommonVars) && modelvars[k].pub==0)     )
        readExpression(modelvars[k].func,rd_hiddenVars,act_hiddenVars,NULL); 
+
    kk=0;
-   for (i = 2; i <= nin+nout; i++)
+   for (i = 2; i <= MAXINOUT; i++)
    for (j = 1; j <= i - 1; j++)
    { k=scalarProductPos(i,j); 
      switch(key)
@@ -124,7 +128,7 @@ int initvararray(int nsub, char key, int width)
       
    nvar=0; nfunc=0;
    
-   if(key=='R' ||key=='R'||key== 'M') for(k=0;k<=nmodelvar;k++) strcpy(vararr[k].alias, modelvars[k].varname);
+   if(key=='F' ||key=='R'||key== 'M') for(k=0;k<=nmodelvar;k++) strcpy(vararr[k].alias, modelvars[k].varname);
    else     
    if(key=='c')
    {   
@@ -149,7 +153,7 @@ int initvararray(int nsub, char key, int width)
        vararr[k].used=0; 
        vararr[k].num=0;
        modelvars[k].pub=0;
-   } else if(key=='m')
+   }
    
-   return 1;
+   return 0;
 } 
