@@ -65,6 +65,12 @@ extern double complex  hAAeven(double MH, double alphaMH, int Nitems, ...);
 extern double complex  hGGodd(double MH, double alphaMH, int Nitems, ...);
 extern double complex  hAAodd(double MH, double alphaMH, int Nitems, ...);
 
+extern double complex lAAhiggs(char*hName);
+extern double complex lGGhiggs(char*hName);
+extern double complex lAA5higgs(char*hName);
+extern double complex lGG5higgs(char*hName);
+
+
 /* To avoid avto-prototyping  
 
 extern double  sqrt(double);
