@@ -7,12 +7,11 @@
 #include "nType.h"
 
 extern double alpha_2(double);
-typedef REAL (DNN)(double, REAL *,REAL*,int *);
+typedef REAL (DNN)(double, REAL *,REAL*,double*, int *);
 typedef REAL (FNN)(double,REAL*,REAL*,COMPLEX*,REAL*,REAL*);
 
-extern  double Fmax;
 extern  REAL Helicity[2];
-extern  REAL HelicityN[2];
+
 extern  int    CalcConst;
 extern  int    indx_(int k,int l);
 extern  void   sprod_(int ntot, REAL * momenta, REAL*DP);
